doapfiend.plugins.text

Package doapfiend :: Package plugins :: Module text |
[hide private]
[frames] | no frames]

# Module text

source code

# Plain text serializer

This plugin outputs DOAP in human-readable plain text

Classes | [hide private]
| OutputPlugin Class for formatting DOAP output
| DoapPrinter Prints DOAP in human readable text

Functions | [hide private]
string |
pretty_name(field) Convert DOAP element name to pretty printable label Shorten some labels for formatting purposes | source code
string |
misc_field(label, text) Print colorized and justified single label value pair | source code

Variables | [hide private]
| FOAF = `rdflib.URIRef('http://xmlns.com/foaf/0.1/')`
| LOG = `logging.getLogger(__name__)`

Function Details | [hide private]

### pretty_name(field) | source code
Convert DOAP element name to pretty printable label Shorten some labels for formatting purposes Parameters: `field` (`string`) - Text to be formatted Returns: string formatted string

### misc_field(label, text) | source code
Print colorized and justified single label value pair Parameters: `label` (string) - A label `text` (string) - Text to print Returns: string Colorized, left-justified text with label